@@ -1,17 +1,13 @@
 """Fixtures for tests."""
+from __future__ import annotations
+
 import pathlib
 import typing as t
 
-import docutils.parsers.rst
 import pytest
 
 from rstcheck_core import _extras
 
-
-if _extras.SPHINX_INSTALLED:
-    import sphinx.application
-
-
 REPO_DIR = pathlib.Path(__file__).resolve().parents[1].resolve()
 TESTING_DIR = REPO_DIR / "testing"
 EXAMPLES_DIR = TESTING_DIR / "examples"
@@ -24,14 +20,12 @@ def _patch_docutils_directives_and_roles_dict_fixture(monkeypatch: pytest.Monkey
     This patch is required when tests are run in parallel (default), because they would
     under the hood all write to the same state dicts otherwise and influence each other.
     """
-    test_dict_directives: t.Dict[str, t.Any] = {}
-    test_dict_roles: t.Dict[str, t.Any] = {}
+    test_dict_directives: dict[str, t.Any] = {}
+    test_dict_roles: dict[str, t.Any] = {}
 
     if _extras.SPHINX_INSTALLED:
-        monkeypatch.setattr(
-            sphinx.application.docutils.directives, "_directives", test_dict_directives
-        )
-        monkeypatch.setattr(sphinx.application.docutils.roles, "_roles", test_dict_roles)
+        monkeypatch.setattr("sphinx.util.docutils.directives._directives", test_dict_directives)
+        monkeypatch.setattr("sphinx.util.docutils.roles._roles", test_dict_roles)
     else:
-        monkeypatch.setattr(docutils.parsers.rst.directives, "_directives", test_dict_directives)
-        monkeypatch.setattr(docutils.parsers.rst.roles, "_roles", test_dict_roles)
+        monkeypatch.setattr("docutils.parsers.rst.directives._directives", test_dict_directives)
+        monkeypatch.setattr("docutils.parsers.rst.roles._roles", test_dict_roles)
